@@ -4,6 +4,8 @@
 # date: 2021/7/12 11:32
 
 from urllib.parse import urlencode
+import time
+import random
 
 
 def splice_url(host, param):
@@ -30,3 +32,15 @@ def parse_cookie(cookie, sep='; '):
         cookie_dict[kv[0]] = '='.join(kv[1:])
     return cookie_dict
 
+
+def random_time(a=2, b=5):
+    """
+    获取一个随机浮点数
+    :param a: 最小值
+    :param b: 最大值
+    :return:
+    """
+    if a >= b:
+        a, b = 2, 5
+    return round(random.uniform(a, b), 2)
+
